@@ -289,7 +289,8 @@ sub update {
     }
   }
   elsif (ref($target) && UNIVERSAL::isa($target, 'Net::LDAP::LDIF')) {
-    $target->write_entry($self);
+    require Net::LDAP::Message;
+    $target->write_entry($self, %opt);
     $mesg = Net::LDAP::Message::Dummy->new();
     $mesg->set_error(LDAP_OTHER, $target->error())
       if ($target->error());
